==> breeze_website_builder_6.5.0.tar.gz: manage/js/browse_template.js <==
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 6/30/2013	ELL

var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
var popup_msg = new PopupMsg(param_array);

window.parent.document.title = document.title;

function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#upload_template", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}

function DeleteConfirm()
{
	popup_msg.top_offset = 0;
	popup_msg.left_offset = 300;
	popup_msg.popup_msg_type = 3;
	popup_msg.popup_msg_cell = UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG;
	popup_msg.popup_button_2_span = YES_WORD;
	popup_msg.popup_button_1_span = NO_WORD;
	popup_msg.popup_timeout = -1;
	popup_msg.ShowPopupMsg();
	document.getElementById("popup_button_2_span").onclick = function () { popup_msg.HidePopupMsg(); };
	document.getElementById("popup_button_1_span").onclick = function () { UncheckDelete(); };

}

function UncheckDelete()
{
	document.getElementById("delete_all_pages").checked = false;
	popup_msg.HidePopupMsg();
}

function ShowUploadingMsg()
{
	popup_msg.popup_msg_type = 1;
	popup_msg.status_msg = UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG;
	popup_msg.popup_timeout = 5000;
	popup_msg.top_offset = 50;
	popup_msg.left_offset = 500;
	popup_msg.ShowPopupMsg();
	
	document.getElementById("uploading_gif").style.display = "inline";
	
	document.getElementById("frmUploadTemplate").submit();
}

==> breeze_website_builder_6.6.18.tar.gz: manage/js/browse_template.js <==
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 6/30/2013	ELL

var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
var popup_msg = new PopupMsg(param_array);

window.parent.document.title = document.title;

function OpenHelpWindow()
{
	window.open(http + "breezewebsitebuilder.com/docs/cms/help.html#upload_template", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}

function DeleteConfirm()
{
	popup_msg.top_offset = 0;
	popup_msg.left_offset = 300;
	popup_msg.popup_msg_type = 3;
	popup_msg.popup_msg_cell = UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG;
	popup_msg.popup_button_2_span = YES_WORD;
	popup_msg.popup_button_1_span = NO_WORD;
	popup_msg.popup_timeout = -1;
	popup_msg.ShowPopupMsg();
	document.getElementById("popup_button_2_span").onclick = function () { popup_msg.HidePopupMsg(); };
	document.getElementById("popup_button_1_span").onclick = function () { UncheckDelete(); };

}

function UncheckDelete()
{
	document.getElementById("delete_all_pages").checked = false;
	popup_msg.HidePopupMsg();
}

function ShowUploadingMsg()
{
	popup_msg.popup_msg_type = 1;
	popup_msg.status_msg = UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG;
	popup_msg.popup_timeout = 5000;
	popup_msg.top_offset = 50;
	popup_msg.left_offset = 500;
	popup_msg.ShowPopupMsg();
	
	document.getElementById("uploading_gif").style.display = "inline";
	
	document.getElementById("frmUploadTemplate").submit();
}
